DescriptionThis change reduces runtime of a minimal test gadget
from 2800ms to 2100ms in Chrome Beta (16.0),
from 2300ms to 1800ms in Firefox Aurora (10.0),
from 2300ms to 2100ms in Firefox Beta (9.0),
from 1700ms to 1200ms in Safari 5.1.2
Basically, a much of the cost of es53+domado startup is freeze,
and much of the cost of freeze is iterating over object properties,
which includes inherited properties which have to be ignored.
This change tries to use a native Object.keys function to do
a fast initial filtering of the properties.
Patch Set 1 #
Total comments: 1
Patch Set 2 : faster es53 freeze #Patch Set 3 : faster es53 freeze #MessagesTotal messages: 8
|